# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

import ubuntuuitoolkit as uitk

from ubuntu_system_tests.helpers.autopilot import override_proxy_timeout

logger = logging.getLogger(__name__)


def get_notification(root, notification_class, obj_name='notification1',
                     timeout=60, **kwargs):
    """
    Static method to return a notification object from the provided
    introspection tree.

    :param root: Root of the introspection tree to examine
    :param notification_class: The class name of notification required
    :param obj_name: The name of the required notification object
    :param timeout: Length of time to wait for notification to appear
    :param kwargs: Any othery keyword parameters to identify required
                   notification
    :return: Notification object meeting required criteria

    """
    with override_proxy_timeout(root, timeout):
        return root.wait_select_single(
            notification_class, objectName=obj_name, **kwargs)


class Notifications(uitk.UbuntuUIToolkitCustomProxyObjectBase):

    """Class to return notification objects of specific types."""

    def get_new_message_notification(self, timeout=60):
        from ubuntu_system_tests.helpers.notifications import new_message
        return get_notification(self, new_message.Notification)

    def get_provider_notification(self, timeout=60):
        from ubuntu_system_tests.helpers.notifications import confirmation
        return get_notification(self, confirmation.Notification)

    def get_download_finished_notification(self, timeout=60):
        from ubuntu_system_tests.helpers.notifications import download_finished
        return get_notification(self, download_finished.Notification)

    def get_incoming_call_notification(self, timeout=60):
        from ubuntu_system_tests.helpers.notifications import incoming_call
        return get_notification(
            self, incoming_call.Notification,
            secondaryIconSource='image://theme/incoming-call')
