# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot.exceptions import StateNotFoundError

from ubuntu_system_tests import config
from ubuntu_system_tests.helpers.telephony import Telephony
from ubuntu_system_tests.tests.base import BaseUbuntuSystemTestCase


class BaseTelephonyTestCase(BaseUbuntuSystemTestCase):
    """Base class to be used for all telephony tests."""

    def setUp(self):
        """Base class setUp method."""
        super().setUp()
        self.config_stack = config.get_device_config_stack()
        credentials = {'AccountSid': self.get_telephony_service_account_id(),
                       'AuthToken': self.get_telephony_service_auth_token()}
        self.telephony = Telephony(credentials)

    def get_telephony_service_account_id(self):
        """Return account id for telephony service."""
        return self.config_stack.get('_twilio_account_sid')

    def get_telephony_service_auth_token(self):
        """Return auth token for telephony service."""
        return self.config_stack.get('_twilio_auth_token')

    def get_telephony_service_number1(self):
        """Return the number to call and message from."""
        return self.config_stack.get('telephony_service_number1')

    def get_telephony_service_number2(self):
        """Return the number to call and message from."""
        return self.config_stack.get('telephony_service_number2')

    def get_device_phone_number(self):
        """Return the number to send messages and calls to."""
        return self.config_stack.get('device_phone_number')

    def clear_provider_notifications(self, timeout=10):
        """
        Clear any network provider notifications displayed on screen after
        a call is made or message is sent.

        """
        while True:
            notification_list = self.shell.get_notifications_list()
            try:
                provider_notif = notification_list.get_provider_notification(
                    timeout=timeout)
            except StateNotFoundError:
                return
            provider_notif.press_ok()
